#graph.R
#
#This file graphs the figures in
#"A Trapped Factors Model of Innovation,"
#Bloom, Nicholas, Romer, Paul, Terry, Stephen J., and Van Reenen, John (2012).
#
#If you have questions about the code, please contact Stephen Terry at sterry@stanford.edu.
#
#February 27, 2013

rm(list=ls())
library(matlab)

load(file="graphout_tf.rda")
load(file="graphout_fm.rda")
T = dim(graphout.tf)[1]-1
assign('beta',1/1.02);  #discount rate
g.phi = graphout.fm$g[1]
g.phi.prime = graphout.fm$g[T+1]
q.phi=graphout.fm$q[1]
q.phi.prime=graphout.fm$q[T+1]
r.phi=graphout.fm$r[1]
r.phi.prime=graphout.fm$r[T+1]
#create graph A: micro graph

scale = 1000/graphout.fm$M1[1]
numperbefore = 1
numperafter = 7

#get axis right
lengthgraphA = numperbefore + numperafter+1
graphA = zeros(lengthgraphA,4)
graphA[(numperbefore+1):lengthgraphA,1]=(1:(numperafter+1))
graphA[1:numperbefore,1] = linspace(-numperbefore+1,0,numperbefore)

#FM patents
graphA[(numperbefore+1):lengthgraphA,2] = scale*graphout.fm$M1[1:(numperafter+1)]
for (t in (1:numperbefore)){
  graphA[numperbefore+1-t,2]=graphA[numperbefore+1-t+1,2]/(1+g.phi)
}

#industry 1 patents
graphA[(numperbefore+1):lengthgraphA,3] = scale*graphout.tf$M1[1:(numperafter+1)]
for (t in (1:numperbefore)){
  graphA[numperbefore+1-t,3]=graphA[numperbefore+1-t+1,3]/(1+g.phi)
}

#industry 2 patents
graphA[(numperbefore+1):lengthgraphA,4] = scale*graphout.tf$M2[1:(numperafter+1)]
for (t in (1:numperbefore)){
  graphA[numperbefore+1-t,4]=graphA[numperbefore+1-t+1,4]/(1+g.phi)
}

#jpeg(file="pandp_figure2.jpg",height=668,width=668,res=250,pointsize=8,family="sans")
jpeg(file="pandp_figure2.jpg",height=715,width=715,res=250,pointsize=8,family="sans")
plot(graphA[,1],graphA[,4],type="l",col=4,xlab="Period",ylab="Number of new patents",lty=1)
title("Figure 2: Industry patent flows",line=3)
title("increase with import exposure",line=2)
lines(graphA[,1],graphA[,3],type="l",col=2,lty=2)
lines(graphA[,1],graphA[,2],type="l",col=1,lty=1)
points(graphA[,1],graphA[,2],pch=4)
legend("bottomright",c("Shocked Industry","No Shock Industry","Fully mobile"),col=c(4,2,1),lty=c(1,2,1),pch=c(-1,-1,4),bty="n")
dev.off()

win.metafile(file="pandp_figure2.wmf",height=2.67,width=2.67,pointsize=8,family="sans")
plot(graphA[,1],graphA[,4],type="l",col=4,xlab="Period",ylab="Number of new patents",main="Figure 2: Industry patent flows",lty=1)
lines(graphA[,1],graphA[,3],type="l",col=2,lty=2)
lines(graphA[,1],graphA[,2],type="l",col=1,lty=1)
points(graphA[,1],graphA[,2],pch=4)
legend("bottomright",c("Shocked Industry","No Shock Industry","Fully mobile"),col=c(4,2,1),lty=c(1,2,1),pch=c(-1,-1,4),bty="n")
dev.off()


pdf(file="micro_graph.pdf")
plot(graphA[,1],graphA[,4],type="l",col=4,xlab="Period",ylab="Number of New Patents",main="Industry Patent Flows")
lines(graphA[,1],graphA[,3],type="l",col=2)
lines(graphA[,1],graphA[,2],type="l",col=1)
points(graphA[,1],graphA[,4],pch=1,col=4)
points(graphA[,1],graphA[,3],pch=2,col=2)
points(graphA[,1],graphA[,2],pch=3,col=1)
legend("bottomright",c("Shocked Industry","No Shock Industry","Fully mobile"),col=c(4,2,1),lty=c(1,1,1),pch=c(1,2,3),bty="n")
dev.off()

data = zeros(5,2)
data[,1]=c(1,2,3,4,5)
data[,2]=100*c(.165,.185,.199,.215,.23)

jpeg(file="pandp_figure1.jpg",height=750,width=750,res=250,pointsize=8,family="sans")
barplot(data[,2],border=NA,space = 0.5,names.arg=data[,1],col=4,ylab="Percent change in IT intensity",xlab="Quintiles of growth in Chinese imports",ylim=c(0,30))
title("Figure 1: IT intensity grows with",line=3)
title("exposure to Chinese imports",line=2)
dev.off()

#create graph B - macro variety growth difference
graphB = zeros(T+1,2)

graphB[,1]=(1:(T+1))
graphB[,2]=100*log(graphout.tf$A/graphout.fm$A)

#create graph C - FM transition growth rates

pdf(file="fm_transition.pdf")
par(mfrow=c(4,2))

plot(1:(T+1),100*graphout.fm$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.fm$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.fm$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),100*graphout.fm$r,type="l",main="Western Interest Rate",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$r,pch=1)
lines(1:(T+1),100*r.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*r.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),100*graphout.fm$rstar,type="l",main="Eastern Interest Rate",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$rstar,pch=1)
lines(1:(T+1),100*r.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*r.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$u[2:T]/graphout.fm$u[1:(T-1)]-1),100*g.phi.prime),type="l",main="Western Cons Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$u[2:T]/graphout.fm$u[1:(T-1)]-1),100*g.phi.prime),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


plot(1:(T+1),c(100*g.phi,100*(graphout.fm$ustar[2:T]/graphout.fm$ustar[1:(T-1)]-1),100*g.phi.prime),type="l",main="Eastern Cons Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$ustar[2:T]/graphout.fm$ustar[1:(T-1)]-1),100*g.phi.prime),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


dev.off()



#create graph C - tf transition growth rates

pdf(file="tf_transition.pdf")
par(mfrow=c(4,2))

plot(1:(T+1),100*graphout.tf$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.tf$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.tf$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.tf$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),100*graphout.tf$r,type="l",main="Western Interest Rate",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.tf$r,pch=1)
lines(1:(T+1),100*r.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*r.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),100*graphout.tf$rstar,type="l",main="Eastern Interest Rate",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.tf$rstar,pch=1)
lines(1:(T+1),100*r.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*r.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$u[2:T]/graphout.tf$u[1:(T-1)]-1),100*g.phi.prime),type="l",main="Western Cons Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$u[2:T]/graphout.tf$u[1:(T-1)]-1),100*g.phi.prime),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


plot(1:(T+1),c(100*g.phi,100*(graphout.tf$ustar[2:T]/graphout.tf$ustar[1:(T-1)]-1),100*g.phi.prime),type="l",main="Eastern Cons Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$ustar[2:T]/graphout.tf$ustar[1:(T-1)]-1),100*g.phi.prime),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


dev.off()


#create graph D - TF - FM levels

pdf(file="tf_effect.pdf")
par(mfrow=c(4,2))

plot(1:(T+1),100*log(graphout.tf$A/graphout.fm$A),type="l",main="Aggregate Varieties",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*log(graphout.tf$A/graphout.fm$A),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)

plot(1:(T+1),100*(graphout.tf$q-graphout.fm$q),type="l",main="Exchange Rate",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*(graphout.tf$q-graphout.fm$q),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)

plot(1:(T+1),100*(graphout.tf$r-graphout.fm$r),type="l",main="Western Interest Rate",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*(graphout.tf$r-graphout.fm$r),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)


plot(1:(T+1),100*(graphout.tf$rstar-graphout.fm$rstar),type="l",main="Eastern Interest Rate",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*(graphout.tf$rstar-graphout.fm$rstar),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)

plot(1:(T+1),100*log(graphout.tf$Y/graphout.fm$Y),type="l",main="Western Output",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*log(graphout.tf$Y/graphout.fm$Y),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)


plot(1:(T+1),100*log(graphout.tf$Ystar/graphout.fm$Ystar),type="l",main="Eastern Output",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*log(graphout.tf$Ystar/graphout.fm$Ystar),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)

plot(1:(T+1),100*log(graphout.tf$u/graphout.fm$u),type="l",main="Western Consumption",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*log(graphout.tf$u/graphout.fm$u),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)


plot(1:(T+1),100*log(graphout.tf$ustar/graphout.fm$ustar),type="l",main="Eastern Consumption",xlab="Period",ylab="% TF - FM",col=1)
points(1:(T+1),100*log(graphout.tf$ustar/graphout.fm$ustar),pch=1)
lines(1:(T+1),zeros(T+1,1),col=4)

dev.off()

#create graph E

pdf(file="phi_graph.pdf")
plot(1:(T+1),100*graphout.fm$phi,type="l",main="Phi",xlab="Period",ylab="% Goods off-Restriction",col=1)
points(1:(T+1),100*graphout.fm$phi,pch=1)
dev.off()



#welfare calculations

welfare.length = 15000
u.mat=zeros(welfare.length,4)
betas=zeros(welfare.length,1)
u.mat[1:(T+1),1]=graphout.tf$u
u.mat[1:(T+1),2]=graphout.tf$ustar
u.mat[1:(T+1),3]=graphout.fm$u
u.mat[1:(T+1),4]=graphout.fm$ustar

betas[1]=beta

for (t in (2:welfare.length)){
  betas[t]=beta*betas[t-1]
}

for (t in ((T+2):welfare.length)) {
  
  u.mat[t,]=(1+g.phi.prime)*u.mat[t-1,]
  
}

Wtf = sum(betas*log(u.mat[,1]))
Wstartf = sum(betas*log(u.mat[,2]))
Wfm = sum(betas*log(u.mat[,3]))
Wstarfm = sum(betas*log(u.mat[,4]))

x = 100*(exp( (1-beta) *(Wtf-Wfm)  )-1)
xstar = 100*(exp( (1-beta) *(Wstartf-Wstarfm)  )-1)

sink(file="welfare.txt",append=FALSE)
cat('  ','\n')
cat('Western Cons Equivalent in % = ',x,'\n')
cat('Eastern Cons Equivalent in % = ',xstar,'\n')
cat('  ','\n')

cat('Diff in Diff Patent Growth in % = ',100*log(graphout.tf$M2[2]/graphout.tf$M1[2]),'\n')
cat('  ','\n')

cat('Table 1','\n')
cat('Pre-Shock phi = ',100*graphout.fm$phi[1],'\n')
cat('Post-Shock phi = ',100*graphout.fm$phi[2],'\n')
cat('Pre-Shock I/Yg = ',.021,'\n')
cat('Post-Shock I/Yg = ',.02325,'\n')
cat('Pre-Shock g (growth rate) = ',g.phi,'\n')
cat('Post-Shock g (growth rate)= ',g.phi.prime,'\n')
cat('Pre-Shock q (x-rate) = ',q.phi,'\n')
cat('Post-Shock q (x-rate) = ',q.phi.prime,'\n')
cat('Pre-Shock r (interest rate)= ',r.phi,'\n')
cat('Post-Shock r (interest rate) = ',r.phi.prime,'\n')


sink(file=NULL)




#create graph C - FM transition growth rates

pdf(file="fm_var_exch.pdf")
par(mfrow=c(2,2))

plot(1:(T+1),100*graphout.fm$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.fm$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.fm$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)


plot(1:(T+1),100*graphout.fm$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.fm$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.fm$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)

dev.off()



pdf(file="fm_output.pdf")
par(mfrow=c(2,2))


plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


dev.off()



pdf(file="tf_var_exch.pdf")
par(mfrow=c(2,2))

plot(1:(T+1),100*graphout.tf$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.tf$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.tf$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.tf$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)
dev.off()
pdf(file="tf_output.pdf")
par(mfrow=c(2,2))


plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


dev.off()

pdf(file="tf_trans4.pdf")
par(mfrow=c(2,2))


plot(1:(T+1),100*graphout.tf$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.tf$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.tf$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.tf$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Y[2:(T+1)]/graphout.tf$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.tf$Ystar[2:(T+1)]/graphout.tf$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)


dev.off()


pdf(file="fm_trans4.pdf")
par(mfrow=c(2,2))

plot(1:(T+1),100*graphout.fm$g,type="l",main="Variety Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),100*graphout.fm$g,pch=1)
lines(1:(T+1),100*g.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),100*g.phi*ones((T+1),1),col=2,lty=2)

plot(1:(T+1),graphout.fm$q,type="l",main="Exchange Rate",xlab="Period",ylab="West/East",col=1)
points(1:(T+1),graphout.fm$q,pch=1)
lines(1:(T+1),q.phi.prime*ones((T+1),1),col=4)
lines(1:(T+1),q.phi*ones((T+1),1),col=2,lty=2)




plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),type="l",main="Western Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Y[2:(T+1)]/graphout.fm$Y[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)

plot(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),type="l",main="Eastern Output Growth",xlab="Period",ylab="%",col=1)
points(1:(T+1),c(100*g.phi,100*(graphout.fm$Ystar[2:(T+1)]/graphout.fm$Ystar[1:T]-1)),pch=1)
lines(1:(T+1),100*g.phi.prime*ones(T+1,1),col=4)
lines(1:(T+1),100*g.phi*ones(T+1,1),col=2,lty=2)
dev.off()
